@@ -317,7 +317,7 @@ def create_description(name, roadName, startMarker, endMarker, typeOfWork, start
     return f"Event {name}, on {roadName}, between mile markers {startMarker} and {endMarker}. {typeOfWork}. Running between {startTime} and {endTime}"
 
 
-def get_improved_geometry(coordinates, event_status):
+def get_improved_geometry(coordinates, event_status, id):
     if event_status != "active":
         return coordinates
 
@@ -328,11 +328,12 @@ def get_improved_geometry(coordinates, event_status):
     endRouteParams = cdot_geospatial_api.get_route_and_measure(endPoint)
 
     if not startRouteParams or not endRouteParams:
-        logging.debug(
-            "1 or more routes not found, not generating improved geometry")
+        logging.info(
+            f"1 or more routes not found, not generating improved geometry: {id}")
         return coordinates
     if startRouteParams['Route'] != endRouteParams['Route']:
-        logging.debug("Routes did not match, not generating improved geometry")
+        logging.info(
+            f"Routes did not match, not generating improved geometry: {id}")
         return coordinates
 
     initialDirection = polygon_tools.get_road_direction_from_coordinates(
@@ -404,7 +405,7 @@ def create_rtdh_standard_msg(pd, isIncident):
         pd.get("properties/laneImpacts"), pd.get("properties/direction"))
     if direction != recorded_direction and all_lanes_open(lane_impacts):
         return {}
-    
+
     event_status = date_tools.get_event_status(start_date, end_date)
 
     return {
@@ -417,7 +418,7 @@ def create_rtdh_standard_msg(pd, isIncident):
                 "id": pd.get("properties/id", default="") + '_' + direction,
                 "last_updated_timestamp": pd.get('properties/lastUpdated', date_tools.get_unix_from_iso_string, default=0),
             },
-            "geometry": get_improved_geometry(coordinates, event_status),
+            "geometry": get_improved_geometry(coordinates, event_status, pd.get("properties/id", default="") + '_' + direction),
             "header": {
                 "description": description,
                 "start_timestamp": date_tools.date_to_unix(start_date),
